about summary refs log tree commit diff stats
path: root/src/tools
diff options
context:
space:
mode:
Diffstat (limited to 'src/tools')
-rw-r--r--src/tools/aesgcm_download.c12
-rw-r--r--src/tools/aesgcm_download.h8
-rw-r--r--src/tools/autocomplete.c8
-rw-r--r--src/tools/autocomplete.h8
-rw-r--r--src/tools/bookmark_ignore.c8
-rw-r--r--src/tools/bookmark_ignore.h8
-rw-r--r--src/tools/clipboard.c8
-rw-r--r--src/tools/clipboard.h8
-rw-r--r--src/tools/editor.c8
-rw-r--r--src/tools/editor.h8
-rw-r--r--src/tools/http_common.c8
-rw-r--r--src/tools/http_common.h8
-rw-r--r--src/tools/http_download.c12
-rw-r--r--src/tools/http_download.h8
-rw-r--r--src/tools/http_upload.c12
-rw-r--r--src/tools/http_upload.h8
-rw-r--r--src/tools/parser.c8
-rw-r--r--src/tools/parser.h8
18 files changed, 78 insertions, 78 deletions
diff --git a/src/tools/aesgcm_download.h b/src/tools/aesgcm_download.h
index 796b9389..ef18b02e 100644
--- a/src/tools/aesgcm_download.h
+++ b/src/tools/aesgcm_download.h
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/autocomplete.c b/src/tools/autocomplete.c
index 8c7818e7..5e4a5fe4 100644
--- a/src/tools/autocomplete.c
+++ b/src/tools/autocomplete.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/autocomplete.h b/src/tools/autocomplete.h
index 851dbc0d..4b76e1ae 100644
--- a/src/tools/autocomplete.h
+++ b/src/tools/autocomplete.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/bookmark_ignore.c b/src/tools/bookmark_ignore.c
index 613a956f..5b595253 100644
--- a/src/tools/bookmark_ignore.c
+++ b/src/tools/bookmark_ignore.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2020 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/bookmark_ignore.h b/src/tools/bookmark_ignore.h
index 82e600d1..baff5521 100644
--- a/src/tools/bookmark_ignore.h
+++ b/src/tools/bookmark_ignore.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2020 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/clipboard.c b/src/tools/clipboard.c
index 43f254e8..b7584385 100644
--- a/src/tools/clipboard.c
+++ b/src/tools/clipboard.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/clipboard.h b/src/tools/clipboard.h
index 26283a7a..94c67809 100644
--- a/src/tools/clipboard.h
+++ b/src/tools/clipboard.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/editor.c b/src/tools/editor.c
index 4cd70d9d..d5d937b5 100644
--- a/src/tools/editor.c
+++ b/src/tools/editor.c
@@ -6,20 +6,20 @@
  * Copyright (C) 2022 MarcoPolo PasTonMolo <marcopolopastonmolo@protonmail.com>
  * Copyright (C) 2022 Steffen Jaeckel <jaeckel-floss@eyet-services.de>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/editor.h b/src/tools/editor.h
index 09783f29..dd7de96e 100644
--- a/src/tools/editor.h
+++ b/src/tools/editor.h
@@ -5,20 +5,20 @@
  * Copyright (C) 2022 - 2023 Michael Vetter <jubalh@iodoru.org>
  * Copyright (C) 2022 MarcoPolo PasTonMolo  <marcopolopastonmolo@protonmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/http_common.c b/src/tools/http_common.c
index 02391e63..ed2e6b45 100644
--- a/src/tools/http_common.c
+++ b/src/tools/http_common.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/http_common.h b/src/tools/http_common.h
index 733d4d17..6595fafd 100644
--- a/src/tools/http_common.h
+++ b/src/tools/http_common.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/http_download.h b/src/tools/http_download.h
index f75ba4d7..a0fd61fe 100644
--- a/src/tools/http_download.h
+++ b/src/tools/http_download.h
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/http_upload.h b/src/tools/http_upload.h
index 06145a43..27f3fecb 100644
--- a/src/tools/http_upload.h
+++ b/src/tools/http_upload.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/parser.c b/src/tools/parser.c
index 93c765f5..8dc78b85 100644
--- a/src/tools/parser.c
+++ b/src/tools/parser.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/parser.h b/src/tools/parser.h
index 054ab2b7..f06633f1 100644
--- a/src/tools/parser.h
+++ b/src/tools/parser.h
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
diff --git a/src/tools/aesgcm_download.c b/src/tools/aesgcm_download.c
index da935156..f040f797 100644
--- a/src/tools/aesgcm_download.c
+++ b/src/tools/aesgcm_download.c
@@ -5,20 +5,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -47,7 +47,7 @@
 #include <assert.h>
 #include <errno.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "event/client_events.h"
 #include "tools/http_common.h"
 #include "tools/aesgcm_download.h"
@@ -81,7 +81,7 @@ aesgcm_file_get(void* userdata)
     // retrieved from the https:// URL.
     gchar* tmpname = NULL;
     gint tmpfd;
-    if ((tmpfd = g_file_open_tmp("profanity.XXXXXX", &tmpname, NULL)) == -1) {
+    if ((tmpfd = g_file_open_tmp("profani-tty.XXXXXX", &tmpname, NULL)) == -1) {
         http_print_transfer_update(aesgcm_dl->window, aesgcm_dl->id,
                                    "Downloading '%s' failed: Unable to create "
                                    "temporary ciphertext file for writing "
@@ -5,20 +5,20 @@
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -5,20 +5,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -5,20 +5,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
diff --git a/src/tools/http_download.c b/src/tools/http_download.c
index bd34a4ed..37ac9274 100644
--- a/src/tools/http_download.c
+++ b/src/tools/http_download.c
@@ -6,20 +6,20 @@
  * Copyright (C) 2020 William Wennerström <william@wstrm.dev>
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -48,7 +48,7 @@
 #include <assert.h>
 #include <errno.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "event/client_events.h"
 #include "tools/http_download.h"
 #include "config/cafile.h"
@@ -154,7 +154,7 @@ http_file_get(void* userdata)
 
     curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void*)outfh);
 
-    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profanity");
+    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profani-tty");
 
     if (cafile) {
         curl_easy_setopt(curl, CURLOPT_CAINFO, cafile);
@@ -6,20 +6,20 @@
  * Copyright (C) 2019 - 2023 Michael Vetter <jubalh@iodoru.org>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -6,20 +6,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -6,20 +6,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
diff --git a/src/tools/http_upload.c b/src/tools/http_upload.c
index 289dba15..238d71fa 100644
--- a/src/tools/http_upload.c
+++ b/src/tools/http_upload.c
@@ -4,20 +4,20 @@
  *
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
  * This file is part of Profanity.
  *
  * Profanity is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
  * (at your option) any later version.
  *
  * Profanity is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with Profanity.  If not, see <https://www.gnu.org/licenses/>.
+ * along with Profani-tty.  If not, see <https://www.gnu.org/licenses/>.
  *
  * In addition, as a special exception, the copyright holders give permission to
  * link the code of portions of this program with the OpenSSL library under
@@ -45,7 +45,7 @@
 #include <pthread.h>
 #include <assert.h>
 
-#include "profanity.h"
+#include "profani-tty.h"
 #include "event/client_events.h"
 #include "tools/http_upload.h"
 #include "config/cafile.h"
@@ -245,7 +245,7 @@ http_file_put(void* userdata)
     curl_easy_setopt(curl, CURLOPT_WRITEFUNCTION, _data_callback);
     curl_easy_setopt(curl, CURLOPT_WRITEDATA, (void*)&output);
 
-    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profanity");
+    curl_easy_setopt(curl, CURLOPT_USERAGENT, "profani-tty");
 
     fh = upload->filehandle;
 
@@ -4,20 +4,20 @@
  * Copyright (C) 2012 - 2019 James Booth <boothj5@gmail.com>
  *
- * This file is part of Profanity.
+ * This file is part of Profani-tty.
  *
@@ -4,20 +4,20 @@
  *
- * Profanity is free software: you can redistribute it and/or modify
+ * Profani-tty is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation, either version 3 of the License, or
@@ -4,20 +4,20 @@
  * (at your option) any later version.
  *
- * Profanity is distributed in the hope that it will be useful,
+ * Profani-tty is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the